@@ -31,7 +31,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "bonobo-activation/bonobo-activation-i18n.h"
+#include <glib/gi18n.h>
 #include "bonobo-activation/bonobo-activation-private.h"
 
 #include "server.h"
