@@ -423,7 +423,7 @@ bonobo_marshal_ANY__TYPECODE_UINT_EXCEPTION (GClosure     *closure,
 		  g_value_peek_pointer (param_values + 3),
 		  data2);
 
-	g_value_set_boxed_take_ownership (return_value, any);
+	g_value_take_boxed (return_value, any);
 }
 
 
@@ -535,11 +535,8 @@ bonobo_property_bag_foreach_remove_prop (gpointer key,
 
 	bonobo_arg_release (prop->default_value);
 
-	if (prop->docstring)
-		g_free (prop->docstring);
-	
-	if (prop->doctitle)
-		g_free (prop->doctitle);
+	g_free (prop->docstring);
+	g_free (prop->doctitle);
 
 	if (prop->priv->get_prop)
 		g_closure_unref (prop->priv->get_prop);
@@ -677,10 +674,10 @@ flags_gparam_to_bonobo (guint flags)
 {
 	Bonobo_PropertyFlags f = 0;
 
-	if (!flags & G_PARAM_READABLE)
+	if (!(flags & G_PARAM_READABLE))
 		f |= Bonobo_PROPERTY_READABLE;
 
-	if (!flags & G_PARAM_WRITABLE)
+	if (!(flags & G_PARAM_WRITABLE))
 		f |= Bonobo_PROPERTY_WRITEABLE;
 
 	return f;
